==> igniteui-webcomponents-core-3.5.0.tgz: package/esm2015/lib/WebToggleDirectiveDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebToggleViewEventArgsDescriptionMetadata } from "./WebToggleViewEventArgsDescriptionMetadata";
import { WebToggleViewCancelableEventArgsDescriptionMetadata } from "./WebToggleViewCancelableEventArgsDescriptionMetadata";
import { WebToggleDirectiveDescription } from "./WebToggleDirectiveDescription";
/**
 * @hidden
 */
export let WebToggleDirectiveDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebToggleDirectiveDescriptionMetadata extends Base {
        static b(a) {
            if (WebToggleDirectiveDescriptionMetadata.a == null) {
                WebToggleDirectiveDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebToggleDirectiveDescriptionMetadata.c(WebToggleDirectiveDescriptionMetadata.a);
            }
            if (a.j(WebToggleDirectiveDescriptionMetadata.a)) {
                return;
            }
            a.y(WebToggleDirectiveDescriptionMetadata.a);
            WebToggleViewEventArgsDescriptionMetadata.d(a);
            WebToggleViewCancelableEventArgsDescriptionMetadata.d(a);
        }
        static c(a) {
            a.item("__qualifiedNameTS", "String:ToggleDirective");
            a.item("__packageNameWC", "String:grids");
            a.item("Id", "String");
            a.item("OpenedRef", "EventRef::opened:customEvent");
            a.item("OpeningRef", "EventRef::opening:customEvent");
            a.item("ClosedRef", "EventRef::closed:customEvent");
            a.item("ClosingRef", "EventRef::closing:customEvent");
            a.item("AppendedRef", "EventRef::appended:customEvent");
        }
        static d(a) {
            WebToggleDirectiveDescriptionMetadata.b(a);
            a.aa("WebToggleDirective", () => new WebToggleDirectiveDescription());
            a.z("WebToggleDirective", WebToggleDirectiveDescriptionMetadata.a);
        }
    }
    WebToggleDirectiveDescriptionMetadata.$t = /*@__PURE__*/ markType(WebToggleDirectiveDescriptionMetadata, 'WebToggleDirectiveDescriptionMetadata');
    WebToggleDirectiveDescriptionMetadata.a = null;
    return WebToggleDirectiveDescriptionMetadata;
})();

==> igniteui-webcomponents-core-4.2.5.tgz: package/esm2015/lib/WebToggleDirectiveDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebToggleViewEventArgsDescriptionMetadata } from "./WebToggleViewEventArgsDescriptionMetadata";
import { WebToggleViewCancelableEventArgsDescriptionMetadata } from "./WebToggleViewCancelableEventArgsDescriptionMetadata";
import { WebToggleDirectiveDescription } from "./WebToggleDirectiveDescription";
/**
 * @hidden
 */
export let WebToggleDirectiveDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebToggleDirectiveDescriptionMetadata extends Base {
        static b(a) {
            if (WebToggleDirectiveDescriptionMetadata.a == null) {
                WebToggleDirectiveDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebToggleDirectiveDescriptionMetadata.c(WebToggleDirectiveDescriptionMetadata.a);
            }
            if (a.k(WebToggleDirectiveDescriptionMetadata.a)) {
                return;
            }
            a.aa(WebToggleDirectiveDescriptionMetadata.a);
            WebToggleViewEventArgsDescriptionMetadata.d(a);
            WebToggleViewCancelableEventArgsDescriptionMetadata.d(a);
        }
        static c(a) {
            a.item("__qualifiedNameTS", "String:ToggleDirective");
            a.item("__packageNameWC", "String:grids");
            a.item("__skipModuleRegisterWebComponents", "Boolean");
            a.item("__importOverrideWebComponents", "String:igniteui-webcomponents-grids/grids/combined");
            a.item("__importTypesWebComponents", "String:igniteui-webcomponents-grids/grids");
            a.item("__skipSuffix", "Boolean");
            a.item("Id", "String");
            a.item("OpenedRef", "EventRef::opened:customEvent");
            a.item("OpeningRef", "EventRef::opening:customEvent");
            a.item("ClosedRef", "EventRef::closed:customEvent");
            a.item("ClosingRef", "EventRef::closing:customEvent");
            a.item("AppendedRef", "EventRef::appended:customEvent");
        }
        static d(a) {
            WebToggleDirectiveDescriptionMetadata.b(a);
            a.ac("WebToggleDirective", () => new WebToggleDirectiveDescription());
            a.ab("WebToggleDirective", WebToggleDirectiveDescriptionMetadata.a);
        }
    }
    WebToggleDirectiveDescriptionMetadata.$t = /*@__PURE__*/ markType(WebToggleDirectiveDescriptionMetadata, 'WebToggleDirectiveDescriptionMetadata');
    WebToggleDirectiveDescriptionMetadata.a = null;
    return WebToggleDirectiveDescriptionMetadata;
})();
